@@ -1,9 +1,10 @@
 from typing import Tuple, Iterable, Mapping, Callable, List
 from doltpy.core.system_helpers import get_logger
-from sqlalchemy import MetaData, Table, select
+from doltpy.core.write import coerce_dates
+from sqlalchemy import MetaData, Table
 from sqlalchemy.engine import Engine
 from retry import retry
-
+from datetime import datetime, date, time
 
 logger = get_logger(__name__)
 
@@ -44,7 +45,8 @@ def build_source_reader(engine: Engine, reader: Callable[[Engine, Table], TableU
     """
     def inner(tables: List[str]) -> DoltAsTargetUpdate:
         result = {}
-        metadata = MetaData(bind=engine, reflect=True)
+        metadata = MetaData(bind=engine)
+        metadata.reflect()
 
         for table in [table for table_name, table in metadata.tables.items() if table_name in tables]:
             logger.info('Reading tables {}'.format(table))
@@ -72,24 +74,34 @@ def get_table_reader() -> Callable[[Engine, Table], List[dict]]:
 # TODO this is flaky on Dolt, though not at all clear why
 @retry(exceptions=Exception, delay=2, tries=10)
 def get_table_metadata(engine: Engine, table_name: str) -> Table:
-    metadata = MetaData(bind=engine, reflect=True)
+    metadata = MetaData(bind=engine)
+    metadata.reflect()
     return metadata.tables[table_name]
 
 
-def get_target_writer_helper(engine: Engine, get_upsert_statement, update_on_duplicate: bool) -> DoltAsSourceWriter:
+def get_target_writer_helper(engine: Engine,
+                             get_upsert_statement,
+                             update_on_duplicate: bool,
+                             clean_types: Callable[[Iterable[dict]], List[dict]] = None) -> DoltAsSourceWriter:
     """
     Given a database connection returns a function that when passed a mapping from table names to TableUpdate will
     apply the table update. A table update consists of primary key values to drop, and data to insert/update.
     :param engine: a database connection
     :param get_upsert_statement:
     :param update_on_duplicate: indicates whether to update values when encountering duplicate PK, default True
+    :param clean_types: an optional function to clean up the types being written
     :return:
     """
     def inner(table_data_map: DoltAsSourceUpdate):
-        metadata = MetaData(bind=engine, reflect=True)
+        metadata = MetaData(bind=engine)
+        metadata.reflect()
         for table_name, table_update in table_data_map.items():
             table = metadata.tables[table_name]
             pks_to_drop, data = table_update
+            if clean_types:
+                clean_data = clean_types(data)
+            else:
+                clean_data = list(data)
 
             # PKs to be dropped are provided as dicts, we drop them
             if pks_to_drop:
@@ -99,9 +111,9 @@ def get_target_writer_helper(engine: Engine, get_upsert_statement, update_on_dup
             if data:
                 with engine.connect() as conn:
                     if update_on_duplicate:
-                        statement = get_upsert_statement(table, data)
+                        statement = get_upsert_statement(table, clean_data)
                     else:
-                        statement = table.insert().values(data)
+                        statement = table.insert().values(clean_data)
                     conn.execute(statement)
 
     return inner
@@ -114,5 +126,3 @@ def drop_primary_keys(engine: Engine, table: Table, pks_to_drop: Iterable[dict])
         for pk in pks:
             statement = statement.where(table.c[pk].in_([pks_for_row[pk] for pks_for_row in pks_to_drop]))
         conn.execute(statement)
-
-
